@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 # This file is dual licensed under the terms of the Apache License, Version
 # 2.0, and the MIT License.  See the LICENSE file in the root of this
 # repository for complete details.
@@ -10,6 +12,7 @@ import sys
 
 import pytest
 import simplejson
+import six
 
 try:
     import rapidjson
@@ -20,7 +23,6 @@ from freezegun import freeze_time
 
 import structlog
 
-from structlog._compat import StringIO
 from structlog.processors import (
     ExceptionPrettyPrinter,
     JSONRenderer,
@@ -38,20 +40,6 @@ from structlog.threadlocal import wrap_dict
 from .utils import py3_only
 
 
-@pytest.fixture
-def sio():
-    return StringIO()
-
-
-@pytest.fixture
-def event_dict():
-    class A(object):
-        def __repr__(self):
-            return '<A(\o/)>'
-
-    return {'a': A(), 'b': [3, 4], 'x': 7, 'y': 'test', 'z': (1, 2)}
-
-
 class TestKeyValueRenderer(object):
     def test_sort_keys(self, event_dict):
         """
@@ -82,6 +70,17 @@ class TestKeyValueRenderer(object):
             (None, None, event_dict)
         )
 
+    def test_order_missing_dropped(self, event_dict):
+        """
+        Missing keys get dropped
+        """
+        assert (
+            r"y='test' b=[3, 4] a=<A(\o/)> z=(1, 2) x=7" ==
+            KeyValueRenderer(key_order=['c', 'y', 'b', 'a', 'z', 'x'],
+                             drop_missing=True)
+            (None, None, event_dict)
+        )
+
     def test_order_extra(self, event_dict):
         """
         Extra keys get sorted if sort_keys=True.
@@ -95,6 +94,19 @@ class TestKeyValueRenderer(object):
             (None, None, event_dict)
         )
 
+    def test_order_sorted_missing_dropped(self, event_dict):
+        """
+        Keys get sorted if sort_keys=True and extras get dropped.
+        """
+        event_dict['B'] = 'B'
+        event_dict['A'] = 'A'
+        assert (
+            r"y='test' b=[3, 4] a=<A(\o/)> z=(1, 2) x=7 A='A' B='B'" ==
+            KeyValueRenderer(key_order=['c', 'y', 'b', 'a', 'z', 'x'],
+                             sort_keys=True, drop_missing=True)
+            (None, None, event_dict)
+        )
+
     def test_random_order(self, event_dict):
         """
         No special ordering doesn't blow up.
@@ -102,6 +114,21 @@ class TestKeyValueRenderer(object):
         rv = KeyValueRenderer()(None, None, event_dict)
         assert isinstance(rv, str)
 
+    @pytest.mark.parametrize("rns", [True, False])
+    def test_repr_native_str(self, rns):
+        """
+        repr_native_str=False doesn't repr on native strings.
+        """
+        rv = KeyValueRenderer(repr_native_str=rns)(None, None, {
+            "event": "哈", "key": 42, "key2": "哈",
+        })
+
+        cnt = rv.count("哈")
+        if rns and six.PY2:
+            assert 0 == cnt
+        else:
+            assert 2 == cnt
+
 
 class TestJSONRenderer(object):
     def test_renders_json(self, event_dict):
@@ -169,10 +196,13 @@ class TestTimeStamper(object):
         assert 'UNIX timestamps are always UTC.' == e.value.args[0]
 
     def test_insertsUTCUNIXTimestampByDefault(self):
+        """
+        Per default a float UNIX timestamp is used.
+        """
         ts = TimeStamper()
         d = ts(None, None, {})
-        # freezegun doesn't work with time.gmtime :(
-        assert isinstance(d['timestamp'], int)
+        # freezegun doesn't work with time.time. :(
+        assert isinstance(d['timestamp'], float)
 
     @freeze_time('1980-03-25 16:00:00')
     def test_local(self):
@@ -242,6 +272,16 @@ class TestFormatExcInfo(object):
         else:
             pytest.fail("Exception not raised.")
 
+    @py3_only
+    def test_exception_without_traceback(self):
+        """
+        If an Exception is missing a traceback, render it anyway.
+        """
+        rv = format_exc_info(None, None, {
+            "exc_info": Exception("no traceback!")
+        })
+        assert {"exception": "Exception: no traceback!"} == rv
+
 
 class TestUnicodeEncoder(object):
     def test_encodes(self):
@@ -411,21 +451,25 @@ class TestStackInfoRenderer(object):
 
 
 class TestFigureOutExcInfo(object):
-    def test_obtains_exc_info_on_True(self):
+    @pytest.mark.parametrize('true_value', [
+        True, 1, 1.1
+    ])
+    def test_obtains_exc_info_on_True(self, true_value):
         """
-        If True is passed, obtain exc_info ourselves.
+        If the passed argument evaluates to True obtain exc_info ourselves.
         """
         try:
             0/0
         except Exception:
-            assert sys.exc_info() == _figure_out_exc_info(True)
+            assert sys.exc_info() == _figure_out_exc_info(true_value)
         else:
             pytest.fail("Exception not raised.")
 
+    @py3_only
     def test_py3_exception_no_traceback(self):
         """
-        Not sure how likely this is but the ``raise`` docs are a bit vague.
-        If an exception without a traceback is passed it's passed back.
+        Exceptions without tracebacks are simply returned with None for
+        traceback.
         """
         e = ValueError()
-        assert e is _figure_out_exc_info(e)
+        assert (e.__class__, e, None) == _figure_out_exc_info(e)
